==> cottonformation-0.0.4.tar.gz: cottonformation-0.0.4/cottonformation/res/_imp.py <==
# -*- coding: utf-8 -*-

from . import (
    wafregional,
    appmesh,
    quicksight,
    elasticache,
    appflow,
    synthetics,
    lookoutmetrics,
    greengrass,
    athena,
    glue,
    s3,
    elasticbeanstalk,
    pinpoint,
    eventschemas,
    customerprofiles,
    apprunner,
    dms,
    iotanalytics,
    cloudtrail,
    xray,
    ses,
    pinpointemail,
    iot,
    autoscaling,
    cloudfront,
    emr,
    cassandra,
    wafv2,
    opensearchservice,
    mediapackage,
    acmpca,
    ec2,
    iotwireless,
    kinesisanalyticsv2,
    cognito,
    ecs,
    kinesisanalytics,
    config,
    opsworks,
    codedeploy,
    batch,
    databrew,
    applicationautoscaling,
    imagebuilder,
    medialive,
    appsync,
    directoryservice,
    panorama,
    awslambda,
    elasticsearch,
    groundstation,
    iotevents,
    greengrassv2,
    managedblockchain,
    waf,
    networkfirewall,
    datasync,
    apigateway,
    sagemaker,
    appconfig,
    devopsguru,
    resourcegroups,
    ecr,
    efs,
    stepfunctions,
    kinesisfirehose,
    appstream,
    elasticloadbalancing,
    backup,
    gamelift,
    rds,
    dynamodb,
    dlm,
    guardduty,
    cloudwatch,
    ssm,
    route53recoveryreadiness,
    redshift,
    elasticloadbalancingv2,
    budgets,
    mediaconnect,
    wisdom,
    codestar,
    ssmcontacts,
    auditmanager,
    lakeformation,
    networkmanager,
    route53,
    logs,
    kendra,
    s3outposts,
    connect,
    secretsmanager,
    applicationinsights,
    iotsitewise,
    codebuild,
    lightsail,
    cloudformation,
    ssmincidents,
    route53resolver,
    sns,
    apigatewayv2,
    codepipeline,
    msk,
    nimblestudio,
    globalaccelerator,
    ivs,
    amazonmq,
    datapipeline,
    fis,
    iam,
    frauddetector,
    eks,
    servicecatalog,
    location,
    licensemanager,
    mediastore,
    events,
    signer,
    amplify,
    route53recoverycontrol,
    robomaker,
    macie,
    transfer,
    autoscalingplans,
    ask,
    certificatemanager,
    servicediscovery,
    accessanalyzer,
    s3objectlambda,
    iotthingsgraph,
    fsx,
    qldb,
    healthlake,
    mediaconvert,
    ce,
    appintegrations,
    memorydb,
    fms,
    kinesis,
    codecommit,
    emrcontainers,
    neptune,
    sso,
    finspace,
    workspaces,
    mwaa,
    iot1click,
    dax,
    codeguruprofiler,
    opsworkscm,
    codestarnotifications,
    cloud9,
    ram,
    iotfleethub,
    docdb,
    kms,
    detective,
    codegurureviewer,
    iotcoredeviceadvisor,
    timestream,
    aps,
    inspector,
    codeartifact,
    sqs,
    lookoutvision,
    chatbot,
    lookoutequipment,
    codestarconnections,
    rekognition,
    servicecatalogappregistry,
    sdb,
    securityhub,
    cur,
)

==> cottonformation-0.0.6.tar.gz: cottonformation-0.0.6/cottonformation/res/_imp.py <==
# -*- coding: utf-8 -*-

from . import (
    wafregional,
    appmesh,
    quicksight,
    elasticache,
    synthetics,
    appflow,
    lookoutmetrics,
    greengrass,
    glue,
    athena,
    s3,
    elasticbeanstalk,
    pinpoint,
    eventschemas,
    customerprofiles,
    apprunner,
    lex,
    dms,
    iotanalytics,
    cloudtrail,
    xray,
    ses,
    pinpointemail,
    iot,
    autoscaling,
    cloudfront,
    amplifyuibuilder,
    emr,
    cassandra,
    wafv2,
    opensearchservice,
    mediapackage,
    acmpca,
    ec2,
    iotwireless,
    kinesisanalyticsv2,
    cognito,
    ecs,
    kinesisanalytics,
    config,
    opsworks,
    codedeploy,
    databrew,
    batch,
    applicationautoscaling,
    fsx,
    imagebuilder,
    appsync,
    medialive,
    directoryservice,
    awslambda,
    panorama,
    events,
    elasticsearch,
    groundstation,
    iotevents,
    greengrassv2,
    managedblockchain,
    waf,
    networkfirewall,
    lightsail,
    datasync,
    apigateway,
    billingconductor,
    evidently,
    sagemaker,
    appconfig,
    devopsguru,
    ecr,
    resourcegroups,
    efs,
    stepfunctions,
    kinesisfirehose,
    appstream,
    elasticloadbalancing,
    backup,
    gamelift,
    rds,
    dynamodb,
    dlm,
    nimblestudio,
    guardduty,
    cloudwatch,
    ssm,
    route53recoveryreadiness,
    redshift,
    elasticloadbalancingv2,
    budgets,
    mediaconnect,
    wisdom,
    codestar,
    ssmcontacts,
    auditmanager,
    lakeformation,
    networkmanager,
    route53,
    logs,
    kafkaconnect,
    kendra,
    s3outposts,
    connect,
    secretsmanager,
    timestream,
    applicationinsights,
    codebuild,
    iotsitewise,
    cloudformation,
    ssmincidents,
    route53resolver,
    sns,
    inspectorv2,
    apigatewayv2,
    codepipeline,
    msk,
    globalaccelerator,
    ivs,
    amazonmq,
    datapipeline,
    fis,
    iam,
    frauddetector,
    eks,
    appintegrations,
    servicecatalog,
    location,
    licensemanager,
    mediastore,
    signer,
    amplify,
    route53recoverycontrol,
    robomaker,
    macie,
    transfer,
    autoscalingplans,
    ask,
    certificatemanager,
    servicediscovery,
    accessanalyzer,
    s3objectlambda,
    iotthingsgraph,
    refactorspaces,
    qldb,
    healthlake,
    mediaconvert,
    resiliencehub,
    ce,
    memorydb,
    fms,
    kinesis,
    codecommit,
    emrcontainers,
    neptune,
    personalize,
    sso,
    finspace,
    workspaces,
    mwaa,
    iot1click,
    dax,
    rum,
    codeguruprofiler,
    opsworkscm,
    codestarnotifications,
    cloud9,
    rekognition,
    ram,
    iotfleethub,
    docdb,
    kms,
    detective,
    codegurureviewer,
    iotcoredeviceadvisor,
    aps,
    inspector,
    kinesisvideo,
    codeartifact,
    sqs,
    lookoutvision,
    forecast,
    chatbot,
    lookoutequipment,
    codestarconnections,
    servicecatalogappregistry,
    sdb,
    securityhub,
    cur,
)
